==> uimaj-2.11.0-source-release.zip: uimaj-2.11.0/uimaj-core/src/test/java/org/apache/uima/analysis_engine/impl/metadata/MetaDataObjectAssert.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.uima.analysis_engine.impl.metadata;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.extractor.Extractors.byName;

public class MetaDataObjectAssert {
  public static void assertFieldAsEqualButNotSameValue(Object original, Object copy, String field)
  {
    Object originalValue = byName(field).apply(original);
    Object copyValue = byName(field).apply(copy);
    
    // null is considered to be "the same" by AssertJ, but for the given purpose, it is ok.
    if (originalValue == null && copyValue == null) {
      return;
    }
    
    assertThat(copyValue) //
            .isEqualTo(originalValue) //
            .isNotSameAs(originalValue);
  }
}

==> uimaj-3.6.1-source-release.zip: uimaj-3.6.1/uimaj-core/src/test/java/org/apache/uima/analysis_engine/impl/metadata/MetaDataObjectAssert.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.uima.analysis_engine.impl.metadata;

import static org.assertj.core.api.Assertions.assertThat;
import static org.assertj.core.extractor.Extractors.byName;

public class MetaDataObjectAssert {
  public static void assertFieldAsEqualButNotSameValue(Object original, Object copy, String field) {
    Object originalValue = byName(field).apply(original);
    Object copyValue = byName(field).apply(copy);

    // null is considered to be "the same" by AssertJ, but for the given purpose, it is ok.
    if (originalValue == null && copyValue == null) {
      return;
    }

    assertThat(copyValue) //
            .isEqualTo(originalValue) //
            .isNotSameAs(originalValue);
  }
}
